package com.zkqy.execution.produce.dispersed.mapper;

import java.util.List;
import java.util.Map;

import com.zkqy.execution.produce.dispersed.entity.BpmExecuteProcess;
import com.zkqy.system.entity.CommonEntity;
import io.lettuce.core.dynamic.annotation.Param;

/**
 * 流程执行任务Mapper接口
 *
 * @author hzh
 * @date 2023-11-01
 */
public interface BpmExecuteProcessMapper {
    /**
     * 查询流程执行任务
     *
     * @param id 流程执行任务主键
     * @return 流程执行任务
     */
    public BpmExecuteProcess selectBpmExecuteProcessById(Long id);

    /**
     * 查询流程执行任务列表
     *
     * @param bpmExecuteProcess 流程执行任务
     * @return 流程执行任务集合
     */
    public List<BpmExecuteProcess> selectBpmExecuteProcessList(BpmExecuteProcess bpmExecuteProcess);

    /**
     * 新增流程执行任务
     *
     * @param bpmExecuteProcess 流程执行任务
     * @return 结果
     */
    public int insertBpmExecuteProcess(BpmExecuteProcess bpmExecuteProcess);

    /**
     * 修改流程执行任务
     *
     * @param bpmExecuteProcess 流程执行任务
     * @return 结果
     */
    public int updateBpmExecuteProcess(BpmExecuteProcess bpmExecuteProcess);

    /**
     * 删除流程执行任务
     *
     * @param id 流程执行任务主键
     * @return 结果
     */
    public int deleteBpmExecuteProcessById(Long id);

    /**
     * 批量删除流程执行任务
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBpmExecuteProcessByIds(Long[] ids);

    /**
     * 根据当前用户登陆信息得到当前可执行流程
     */
    public List<CommonEntity> queryExecuteProcess(@Param("objectMap") Map<String, Object> objectMap);


    /**
     * 查询流程执行任务
     *
     * @param taskKey 流程执行任务编号唯一标识
     * @return 流程执行任务
     */
    BpmExecuteProcess selectBpmExecuteProcessByTaskKey(String taskKey);

    /**
     * 结束流程
     *
     * @param taskKey
     * @return
     */
    int endProcess(String taskKey);

    /**
     * 修改当前流程执行节点
     *
     * @param taskKey         任务流程标识
     * @param taskNodeKey     当前流程被执行的最后一个节点
     * @param taskNodeNextKey 下一个节点的标识
     * @return
     */
    int updateProcessNode(BpmExecuteProcess bpmExecuteProcess);

    /**
     * 通过formKey查询表单信息
     * @param formKey
     * @return
     */
    Map<String,String> getFromInfo(String formKey);

    /**
     * 根据groupKey查询表格组信息
     */
    Map<String,String> getGroupInfo(String groupKey);

    /**
     * 根据tableKey查询Table表格信息
     */
    Map<String,String> getTableInfo(String tableKey);

    /**
     * 根据tableKey查询Table表格信息
     */
    Map<String,String> getTableSqlInfo(String sqlKey);

    /**
     * 根据动态表格编号查询 drag_table_
     */
    List<Map<String,String>> getTableCondition(String tId);
}